AdRenderValue class final

Implemented types

Constructors

AdRenderValue({required String url, String? width, String? height})

Properties

hashCode int
The hash code for this object.
no setterinherited
height String?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
getter/setter pairoverride
width String?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited