AnimationEffect class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getComputedTiming() ComputedEffectTiming
getTiming() EffectTiming
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateTiming([OptionalEffectTiming? timing]) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited