AudioContextOptionsValue class final
- Implemented types
Constructors
- AudioContextOptionsValue({Object? latencyHint, double? sampleRate, Object? sinkId, Object? renderSizeHint})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- latencyHint ↔ Object?
-
getter/setter pairoverride
- renderSizeHint ↔ Object?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate ↔ double?
-
getter/setter pairoverride
- sinkId ↔ Object?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited