AudioParamDescriptorValue class final

Implemented types

Constructors

AudioParamDescriptorValue({required String name, double? defaultValue, double? minValue, double? maxValue, AutomationRate? automationRate})

Properties

automationRate ChannelCountMode?
getter/setter pairoverride
defaultValue double?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
maxValue double?
getter/setter pairoverride
minValue double?
getter/setter pairoverride
name String
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited