AuthenticationExtensionsPaymentInputsValue class final
- Implemented types
Constructors
- AuthenticationExtensionsPaymentInputsValue({bool? isPayment, String? rpId, String? topOrigin, String? payeeName, String? payeeOrigin, PaymentCurrencyAmount? total, PaymentCredentialInstrument? instrument})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instrument ↔ PaymentCredentialInstrument?
-
getter/setter pairoverride
- isPayment ↔ bool?
-
getter/setter pairoverride
- payeeName ↔ String?
-
getter/setter pairoverride
- payeeOrigin ↔ String?
-
getter/setter pairoverride
- rpId ↔ String?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topOrigin ↔ String?
-
getter/setter pairoverride
- total ↔ PaymentCurrencyAmount?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited