AuthenticationResponseJSONValue class final

Implemented types

Constructors

AuthenticationResponseJSONValue({required Base64URLString id, required Base64URLString rawId, required AuthenticatorAssertionResponseJSON response, String? authenticatorAttachment, required AuthenticationExtensionsClientOutputsJSON clientExtensionResults, required String type_})

Properties

authenticatorAttachment String?
getter/setter pairoverride
clientExtensionResults AuthenticationExtensionsClientOutputsJSON
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairoverride
rawId String
getter/setter pairoverride
response AuthenticatorAssertionResponseJSON
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited