AuthenticatorAssertionResponseJSONValue class final
- Implemented types
Constructors
- AuthenticatorAssertionResponseJSONValue({required Base64URLString clientDataJSON, required Base64URLString authenticatorData, required Base64URLString signature, Base64URLString? userHandle})
Properties
- authenticatorData ↔ String
-
getter/setter pairoverride
- clientDataJSON ↔ String
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature ↔ String
-
getter/setter pairoverride
- userHandle ↔ String?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited