BaseAudioContext class abstract interface

Properties

audioWorklet AudioWorklet
no setter
currentTime double
no setter
destination AudioDestinationNode
no setter
hashCode int
The hash code for this object.
no setterinherited
listener AudioListener
no setter
onstatechange EventHandler?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate double
no setter
state String
no setter

Methods

createAnalyser() AnalyserNode
createBiquadFilter() BiquadFilterNode
createBuffer(int numberOfChannels, int length, double sampleRate) AudioBuffer
createBufferSource() AudioBufferSourceNode
createChannelMerger([int? numberOfInputs]) ChannelMergerNode
createChannelSplitter([int? numberOfOutputs]) ChannelSplitterNode
createConstantSource() ConstantSourceNode
createConvolver() ConvolverNode
createDelay([double? maxDelayTime]) DelayNode
createDynamicsCompressor() DynamicsCompressorNode
createGain() GainNode
createIIRFilter(List<double> feedforward, List<double> feedback) IIRFilterNode
createOscillator() OscillatorNode
createPanner() PannerNode
createPeriodicWave(List<double> real, List<double> imag, [PeriodicWaveConstraints? constraints]) PeriodicWave
createScriptProcessor([int? bufferSize, int? numberOfInputChannels, int? numberOfOutputChannels]) ScriptProcessorNode
createStereoPanner() StereoPannerNode
createWaveShaper() WaveShaperNode
decodeAudioData(Object audioData, [DecodeSuccessCallback? successCallback, DecodeErrorCallback? errorCallback]) Future<AudioBuffer>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited