BiquadFilterOptionsValue class final

Implemented types

Constructors

BiquadFilterOptionsValue({BiquadFilterType? type_, double? q, double? detune, double? frequency, double? gain})

Properties

detune double?
getter/setter pairoverride
frequency double?
getter/setter pairoverride
gain double?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
q double?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ ChannelCountMode?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited