BlobEvent class abstract interface

Constructors

BlobEvent(String type_, BlobEventInit eventInitDict)
factory

Properties

data Blob
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timecode DOMHighResTimeStamp
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited