CSSNumericType class abstract interface

Implementers

Properties

angle int?
getter/setter pair
flex int?
getter/setter pair
frequency int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
length int?
getter/setter pair
percent int?
getter/setter pair
percentHint CSSNumericBaseType?
getter/setter pair
resolution int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited