CharacterBoundsUpdateEventInitValue class final
- Implemented types
Constructors
- CharacterBoundsUpdateEventInitValue({int? rangeStart, int? rangeEnd})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rangeEnd ↔ int?
-
getter/setter pairoverride
- rangeStart ↔ int?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited