ContactInfo class abstract interface

Implementers

Properties

address List<Object>?
getter/setter pair
email List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon List<Blob>?
getter/setter pair
name List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tel List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited