Constructors
- DOMRectReadOnly([double? x, double? y, double? width, double? height])
-
factory
Properties
- bottom → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
no setter
- left → double
-
no setter
- right → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double
-
no setter
- width → double
-
no setter
- x → double
-
no setter
- y → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → Object -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited