ForwardRefComponent<P, T> class final

A forwarded-ref component definition.

The component is callable with an optional Dart ref. Renderers also expose it through React's forwardRef primitive when producing JavaScript.

See https://react.dev/reference/react/forwardRef.

Constructors

ForwardRefComponent(ForwardRefRender<P, T> render)
Creates a forwarded-ref component.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
render ForwardRefRender<P, T>
The render function receiving props and the forwarded ref.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(P props, {ReactRef<T>? ref}) ReactNode
Builds a node with an optional Dart ref.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited