GPUBindGroupLayoutEntry class abstract interface

Implementers

Properties

binding int
getter/setter pair
buffer GPUBufferBindingLayout?
getter/setter pair
externalTexture GPUExternalTextureBindingLayout?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampler GPUSamplerBindingLayout?
getter/setter pair
storageTexture GPUStorageTextureBindingLayout?
getter/setter pair
texture GPUTextureBindingLayout?
getter/setter pair
visibility int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited