GPUBufferDescriptorValue class final
- Implemented types
Constructors
- GPUBufferDescriptorValue({required GPUSize64 size, required GPUBufferUsageFlags usage, bool? mappedAtCreation})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mappedAtCreation ↔ bool?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
getter/setter pairoverride
- usage ↔ int
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited