- Implementers
Properties
- defaultQueue ↔ GPUQueueDescriptor?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requiredFeatures
↔ List<
GPUTextureFormat> ? -
getter/setter pair
-
requiredLimits
↔ Map<
String, GPUSize64> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited