GPUImageCopyTextureValue class final

Implemented types

Constructors

GPUImageCopyTextureValue({required Object texture, GPUIntegerCoordinate? mipLevel, GPUOrigin3D? origin, GPUTextureAspect? aspect})

Properties

aspect GPUBlendFactor?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
mipLevel GPUSize64?
getter/setter pairoverride
origin GPUOrigin2D?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texture Object
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited