GPUImageDataLayoutValue class final

Implemented types

Constructors

GPUImageDataLayoutValue({GPUSize64? offset, GPUSize32? bytesPerRow, GPUSize32? rowsPerImage})

Properties

bytesPerRow GPUSize64?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
offset GPUSize64?
getter/setter pairoverride
rowsPerImage GPUSize64?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited