GPURenderPassLayoutValue class final

Implemented types

Constructors

GPURenderPassLayoutValue({required List<GPUTextureFormat?> colorFormats, GPUTextureFormat? depthStencilFormat, GPUSize32? sampleCount})

Properties

colorFormats List<GPUTextureFormat?>
getter/setter pairoverride
depthStencilFormat GPUBlendFactor?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleCount GPUSize64?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited