GPUTextureBindingLayoutValue class final

Implemented types

Constructors

GPUTextureBindingLayoutValue({GPUTextureSampleType? sampleType, GPUTextureViewDimension? viewDimension, bool? multisampled})

Properties

hashCode int
The hash code for this object.
no setterinherited
multisampled bool?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleType GPUBlendFactor?
getter/setter pairoverride
viewDimension GPUBlendFactor?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited