HTMLCanvasElement class abstract interface

Constructors

HTMLCanvasElement()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair

Methods

captureStream([double? frameRequestRate]) MediaStream
getContext(String contextId, [Object? options]) RenderingContext?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBlob(BlobCallback callback, [String? type_, Object? quality]) → void
toDataURL([String? type_, Object? quality]) String
toString() String
A string representation of this object.
inherited
transferControlToOffscreen() OffscreenCanvas

Operators

operator ==(Object other) bool
The equality operator.
inherited