HTMLEmbedElement class abstract interface

Constructors

HTMLEmbedElement()
factory

Properties

align String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String
getter/setter pair
type_ String
getter/setter pair
width String
getter/setter pair

Methods

getSVGDocument() Document?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited