HTMLFrameElement class abstract interface

Constructors

HTMLFrameElement()
factory

Properties

contentDocument Document?
no setter
contentWindow Object
no setter
frameBorder String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
longDesc String
getter/setter pair
marginHeight String
getter/setter pair
marginWidth String
getter/setter pair
name String
getter/setter pair
noResize bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrolling String
getter/setter pair
src String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited