HTMLSlotElement class abstract interface

Constructors

HTMLSlotElement()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assign([List<Object>? nodes]) → void
assignedElements([AssignedNodesOptions? options]) List<Element>
assignedNodes([AssignedNodesOptions? options]) List<Node>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited