HTMLTableElement class abstract interface

Constructors

HTMLTableElement()
factory

Properties

align String
getter/setter pair
bgColor String
getter/setter pair
border String
getter/setter pair
caption HTMLTableCaptionElement?
getter/setter pair
cellPadding String
getter/setter pair
cellSpacing String
getter/setter pair
frame String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rows HTMLCollection
no setter
rules String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String
getter/setter pair
tBodies HTMLCollection
no setter
tFoot HTMLTableSectionElement?
getter/setter pair
tHead HTMLTableSectionElement?
getter/setter pair
width String
getter/setter pair

Methods

createCaption() HTMLTableCaptionElement
createTBody() HTMLTableSectionElement
createTFoot() HTMLTableSectionElement
createTHead() HTMLTableSectionElement
deleteCaption() → void
deleteRow(int index) → void
deleteTFoot() → void
deleteTHead() → void
insertRow([int? index]) HTMLTableRowElement
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited