Highlight class abstract interface

Constructors

Highlight([List<AbstractRange>? initialRanges])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
priority int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ HighlightType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() HighlightType
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited