IDBVersionChangeEventInitValue class final
- Implemented types
Constructors
- IDBVersionChangeEventInitValue({int? oldVersion, int? newVersion})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- newVersion ↔ int?
-
getter/setter pairoverride
- oldVersion ↔ int?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → IDBCursorDirection -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited