IdentityProviderBrandingValue class final

Implemented types

Constructors

IdentityProviderBrandingValue({String? backgroundColor, String? color, List<IdentityProviderIcon>? icons, String? name})

Properties

backgroundColor CredentialMediationRequirement?
getter/setter pairoverride
color CredentialMediationRequirement?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
icons List<IdentityProviderIcon>?
getter/setter pairoverride
name CredentialMediationRequirement?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited