ItemDetails class abstract interface

Implementers

Properties

description String?
getter/setter pair
freeTrialPeriod String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iconURLs List<String>?
getter/setter pair
introductoryPrice PaymentCurrencyAmount?
getter/setter pair
introductoryPriceCycles int?
getter/setter pair
introductoryPricePeriod String?
getter/setter pair
itemId String
getter/setter pair
price PaymentCurrencyAmount
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionPeriod String?
getter/setter pair
title String
getter/setter pair
type_ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited