MLBatchNormalizationOptionsValue class final
- Implemented types
Constructors
- MLBatchNormalizationOptionsValue({Object? scale, Object? bias, int? axis, double? epsilon})
Properties
- axis ↔ int?
-
getter/setter pairoverride
- bias ↔ Object?
-
getter/setter pairoverride
- epsilon ↔ double?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale ↔ Object?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited