- Implementers
Properties
- bias ↔ Object?
-
getter/setter pair
-
dilations
↔ List<
int> ? -
getter/setter pair
- filterLayout ↔ MLDeviceType?
-
getter/setter pair
- groups ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputLayout ↔ MLDeviceType?
-
getter/setter pair
-
outputPadding
↔ List<
int> ? -
getter/setter pair
-
outputSizes
↔ List<
int> ? -
getter/setter pair
-
padding
↔ List<
int> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
strides
↔ List<
int> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited