MediaCapabilitiesInfoValue class final

Implemented types

Constructors

MediaCapabilitiesInfoValue({required bool supported, required bool smooth, required bool powerEfficient})

Properties

hashCode int
The hash code for this object.
no setterinherited
powerEfficient bool
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smooth bool
getter/setter pairoverride
supported bool
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited