MediaDecodingConfigurationValue class final

Implemented types

Constructors

MediaDecodingConfigurationValue({required MediaDecodingType type_, MediaCapabilitiesKeySystemConfiguration? keySystemConfiguration})

Properties

hashCode int
The hash code for this object.
no setterinherited
keySystemConfiguration MediaCapabilitiesKeySystemConfiguration?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ String
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited