MemoryBreakdownEntryValue class final

Implemented types

Constructors

MemoryBreakdownEntryValue({int? bytes, List<MemoryAttribution>? attribution, List<String>? types})

Properties

attribution List<MemoryAttribution>?
getter/setter pairoverride
bytes int?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types List<String>?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited