MockCameraConfigurationValue class final
- Implemented types
Constructors
- MockCameraConfigurationValue({double? defaultFrameRate, String? facingMode})
Properties
- defaultFrameRate ↔ double?
-
getter/setter pairoverride
- facingMode ↔ String?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited