Navigator class abstract interface

Properties

appCodeName String
no setter
appName String
no setter
appVersion String
no setter
clipboard Clipboard
no setter
connection NetworkInformation
no setter
cookieEnabled bool
no setter
credentials CredentialsContainer
no setter
deviceMemory double
no setter
geolocation Geolocation
no setter
gpu Object
no setter
hardwareConcurrency int
no setter
hashCode int
The hash code for this object.
no setterinherited
language String
no setter
languages List<String>
no setter
locks LockManager
no setter
maxTouchPoints int
no setter
mediaCapabilities MediaCapabilities
no setter
mediaDevices MediaDevices
no setter
mediaSession MediaSession
no setter
mimeTypes MimeTypeArray
no setter
ml Object
no setter
onLine bool
no setter
oscpu String
no setter
pdfViewerEnabled bool
no setter
permissions Permissions
no setter
platform String
no setter
plugins PluginArray
no setter
presentation Object
no setter
product String
no setter
productSub String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceWorker ServiceWorkerContainer
no setter
storage StorageManager
no setter
storageBuckets Object
no setter
usb Object
no setter
userActivation UserActivation
no setter
userAgent String
no setter
userAgentData Object
no setter
vendor String
no setter
vendorSub String
no setter
wakeLock WakeLock
no setter
webdriver bool
no setter
windowControlsOverlay Object
no setter

Methods

canShare([ShareData? data]) bool
clearAppBadge() Future<void>
getBattery() Future<BatteryManager>
getGamepads() List<Gamepad?>
javaEnabled() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerProtocolHandler(String scheme, String url) → void
requestMediaKeySystemAccess(String keySystem, List<MediaKeySystemConfiguration> supportedConfigurations) Future<MediaKeySystemAccess>
requestMIDIAccess([MIDIOptions? options]) Future<MIDIAccess>
sendBeacon(String url, [BodyInit? data]) bool
setAppBadge([int? contents]) Future<void>
share([ShareData? data]) Future<void>
taintEnabled() bool
toString() String
A string representation of this object.
inherited
unregisterProtocolHandler(String scheme, String url) → void
vibrate(VibratePattern pattern) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited