NodeIterator class abstract interface

Properties

filter NodeFilter?
no setter
hashCode int
The hash code for this object.
no setterinherited
pointerBeforeReferenceNode bool
no setter
referenceNode Node
no setter
root Node
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
whatToShow int
no setter

Methods

detach() → void
nextNode() Node?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previousNode() Node?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited