OES_draw_buffers_indexed class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

blendEquationiOES(GLuint buf, GLenum mode) → void
blendEquationSeparateiOES(GLuint buf, GLenum modeRGB, GLenum modeAlpha) → void
blendFunciOES(GLuint buf, GLenum src, GLenum dst) → void
blendFuncSeparateiOES(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha) → void
colorMaskiOES(GLuint buf, GLboolean r, GLboolean g, GLboolean b, GLboolean a) → void
disableiOES(GLenum target, GLuint index) → void
enableiOES(GLenum target, GLuint index) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited