OscillatorOptionsValue class final

Implemented types

Constructors

OscillatorOptionsValue({OscillatorType? type_, double? frequency, double? detune, PeriodicWave? periodicWave})

Properties

detune double?
getter/setter pairoverride
frequency double?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
periodicWave PeriodicWave?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ ChannelCountMode?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited