PaymentDetailsUpdateValue class final
- Implemented types
Constructors
- PaymentDetailsUpdateValue({PaymentItem? total, Object? paymentMethodErrors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentMethodErrors ↔ Object?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total ↔ PaymentItem?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited