PaymentHandlerResponse class abstract interface

Implementers

Properties

details Object?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
methodName String?
getter/setter pair
payerEmail String?
getter/setter pair
payerName String?
getter/setter pair
payerPhone String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress AddressInit?
getter/setter pair
shippingOption String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited