PaymentHandlerResponseValue class final
- Implemented types
Constructors
- PaymentHandlerResponseValue({String? methodName, Object? details, String? payerName, String? payerEmail, String? payerPhone, AddressInit? shippingAddress, String? shippingOption})
Properties
- details ↔ Object?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodName ↔ String?
-
getter/setter pairoverride
- payerEmail ↔ String?
-
getter/setter pairoverride
- payerName ↔ String?
-
getter/setter pairoverride
- payerPhone ↔ String?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingAddress ↔ AddressInit?
-
getter/setter pairoverride
- shippingOption ↔ String?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited