PaymentOptions class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
requestBillingAddress bool?
getter/setter pair
requestPayerEmail bool?
getter/setter pair
requestPayerName bool?
getter/setter pair
requestPayerPhone bool?
getter/setter pair
requestShipping bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingType String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited