PaymentRequestDetailsUpdate class abstract interface

Implementers

Properties

error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
modifiers List<PaymentDetailsModifier>?
getter/setter pair
paymentMethodErrors Object?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddressErrors AddressErrors?
getter/setter pair
shippingOptions List<PaymentShippingOption>?
getter/setter pair
total PaymentCurrencyAmount?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited