PaymentRequestDetailsUpdateValue class final

Implemented types

Constructors

PaymentRequestDetailsUpdateValue({String? error, PaymentCurrencyAmount? total, List<PaymentDetailsModifier>? modifiers, List<PaymentShippingOption>? shippingOptions, Object? paymentMethodErrors, AddressErrors? shippingAddressErrors})

Properties

error String?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
modifiers List<PaymentDetailsModifier>?
getter/setter pairoverride
paymentMethodErrors Object?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddressErrors AddressErrors?
getter/setter pairoverride
shippingOptions List<PaymentShippingOption>?
getter/setter pairoverride
total PaymentCurrencyAmount?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited