PaymentShippingOptionValue class final

Implemented types

Constructors

PaymentShippingOptionValue({required String id, required String label, required PaymentCurrencyAmount amount, bool? selected})

Properties

amount PaymentCurrencyAmount
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairoverride
label String
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited