PointerEvent class abstract interface

Constructors

PointerEvent(String type_, [PointerEventInit? eventInitDict])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
no setter
isPrimary bool
no setter
pointerId int
no setter
pointerType String
no setter
pressure double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tangentialPressure double
no setter
tiltX int
no setter
tiltY int
no setter
twist int
no setter
width double
no setter

Methods

getCoalescedEvents() List<PointerEvent>
getPredictedEvents() List<PointerEvent>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited