PointerEventInit class abstract interface

Implementers

Properties

altitudeAngle double?
getter/setter pair
azimuthAngle double?
getter/setter pair
coalescedEvents List<PointerEvent>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
isPrimary bool?
getter/setter pair
pointerId int?
getter/setter pair
pointerType String?
getter/setter pair
predictedEvents List<PointerEvent>?
getter/setter pair
pressure double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tangentialPressure double?
getter/setter pair
tiltX int?
getter/setter pair
tiltY int?
getter/setter pair
twist int?
getter/setter pair
width double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited