PrivateTokenValue class final

Implemented types

Constructors

PrivateTokenValue({required TokenVersion version, required OperationType operation, RefreshPolicy? refreshPolicy, List<String>? issuers})

Properties

hashCode int
The hash code for this object.
no setterinherited
issuers List<String>?
getter/setter pairoverride
operation OperationType
getter/setter pairoverride
refreshPolicy RefreshPolicy?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version OperationType
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() OperationType
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited