ProgressEventInitValue class final

Implemented types

Constructors

ProgressEventInitValue({bool? lengthComputable, int? loaded, int? total})

Properties

hashCode int
The hash code for this object.
no setterinherited
lengthComputable bool?
getter/setter pairoverride
loaded int?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited