PublicKeyCredential class abstract interface

Properties

authenticatorAttachment String?
no setter
hashCode int
The hash code for this object.
no setterinherited
rawId BufferSource
no setter
response AuthenticatorResponse
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClientExtensionResults() AuthenticationExtensionsClientOutputs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited