PublicKeyCredentialCreationOptions class abstract interface

Implementers

Properties

attestation String?
getter/setter pair
attestationFormats List<String>?
getter/setter pair
authenticatorSelection AuthenticatorSelectionCriteria?
getter/setter pair
challenge BufferSource
getter/setter pair
excludeCredentials List<PublicKeyCredentialDescriptor>?
getter/setter pair
extensions AuthenticationExtensionsClientInputs?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hints List<String>?
getter/setter pair
pubKeyCredParams List<PublicKeyCredentialParameters>
getter/setter pair
rp PublicKeyCredentialRpEntity
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
getter/setter pair
user PublicKeyCredentialUserEntity
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited