PushSubscription class abstract interface

Properties

endpoint String
no setter
expirationTime EpochTimeStamp?
no setter
hashCode int
The hash code for this object.
no setterinherited
options PushSubscriptionOptions
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getKey(PushEncryptionKeyName name) Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() PushSubscriptionJSON
toString() String
A string representation of this object.
inherited
unsubscribe() Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited