RTCDataChannel class abstract interface

Properties

binaryType BinaryType
getter/setter pair
bufferedAmount int
no setter
bufferedAmountLowThreshold int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
no setter
label BinaryType
no setter
maxPacketLifeTime int?
no setter
maxRetransmits int?
no setter
negotiated bool
no setter
onbufferedamountlow EventHandler?
getter/setter pair
onclose EventHandler?
getter/setter pair
onclosing EventHandler?
getter/setter pair
onerror EventHandler?
getter/setter pair
onmessage EventHandler?
getter/setter pair
onopen EventHandler?
getter/setter pair
ordered bool
no setter
protocol BinaryType
no setter
readyState BinaryType
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(String data) → void
toString() BinaryType
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited