RTCError class abstract interface

Constructors

RTCError(RTCErrorInit init, [String? message])
factory

Properties

errorDetail String
no setter
hashCode int
The hash code for this object.
no setterinherited
httpRequestStatusCode int?
no setter
receivedAlert int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sctpCauseCode int?
no setter
sdpLineNumber int?
no setter
sentAlert int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited