RTCIdentityProviderOptionsValue class final
- Implemented types
Constructors
- RTCIdentityProviderOptionsValue({String? protocol, String? usernameHint, String? peerIdentity})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- peerIdentity ↔ RTCBundlePolicy?
-
getter/setter pairoverride
- protocol ↔ RTCBundlePolicy?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usernameHint ↔ RTCBundlePolicy?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited