RTCPeerConnection class abstract interface

Constructors

RTCPeerConnection([RTCConfiguration? configuration])
factory

Properties

canTrickleIceCandidates bool?
no setter
connectionState String
no setter
currentLocalDescription RTCSessionDescription?
no setter
currentRemoteDescription RTCSessionDescription?
no setter
hashCode int
The hash code for this object.
no setterinherited
iceConnectionState String
no setter
iceGatheringState String
no setter
idpLoginUrl RTCBundlePolicy?
no setter
localDescription RTCSessionDescription?
no setter
onconnectionstatechange EventHandler?
getter/setter pair
ondatachannel EventHandler?
getter/setter pair
onicecandidate EventHandler?
getter/setter pair
onicecandidateerror EventHandler?
getter/setter pair
oniceconnectionstatechange EventHandler?
getter/setter pair
onicegatheringstatechange EventHandler?
getter/setter pair
onnegotiationneeded EventHandler?
getter/setter pair
onsignalingstatechange EventHandler?
getter/setter pair
ontrack EventHandler?
getter/setter pair
peerIdentity Future<Object>
no setter
pendingLocalDescription RTCSessionDescription?
no setter
pendingRemoteDescription RTCSessionDescription?
no setter
remoteDescription RTCSessionDescription?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sctp RTCSctpTransport?
no setter
signalingState String
no setter

Methods

addIceCandidate(RTCIceCandidateInit candidate, VoidFunction successCallback, RTCPeerConnectionErrorCallback failureCallback) Future<void>
addTrack(MediaStreamTrack track, [List<MediaStream>? streams]) RTCRtpSender
addTransceiver(Object trackOrKind, [RTCRtpTransceiverInit? init]) RTCRtpTransceiver
close() → void
createAnswer(RTCSessionDescriptionCallback successCallback, RTCPeerConnectionErrorCallback failureCallback) Future<void>
createDataChannel(String label, [RTCDataChannelInit? dataChannelDict]) RTCDataChannel
createOffer(RTCSessionDescriptionCallback successCallback, RTCPeerConnectionErrorCallback failureCallback, [RTCOfferOptions? options]) Future<void>
getConfiguration() RTCConfiguration
getIdentityAssertion() Future<String>
getReceivers() List<RTCRtpReceiver>
getSenders() List<RTCRtpSender>
getStats([MediaStreamTrack? selector]) Future<RTCStatsReport>
getTransceivers() List<RTCRtpTransceiver>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTrack(RTCRtpSender sender) → void
restartIce() → void
setConfiguration([RTCConfiguration? configuration]) → void
setIdentityProvider(String provider, [RTCIdentityProviderOptions? options]) → void
setLocalDescription(RTCLocalSessionDescriptionInit description, VoidFunction successCallback, RTCPeerConnectionErrorCallback failureCallback) Future<void>
setRemoteDescription(RTCSessionDescriptionInit description, VoidFunction successCallback, RTCPeerConnectionErrorCallback failureCallback) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited