RTCRemoteInboundRtpStreamStatsValue class final
- Implemented types
Constructors
Properties
- fractionLost ↔ double?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- localId ↔ String?
-
getter/setter pairoverride
- roundTripTime ↔ double?
-
getter/setter pairoverride
- roundTripTimeMeasurements ↔ int?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalRoundTripTime ↔ double?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited