RTCRtpContributingSourceValue class final

Implemented types

Constructors

RTCRtpContributingSourceValue({required DOMHighResTimeStamp timestamp, required int source, double? audioLevel, required int rtpTimestamp})

Properties

audioLevel double?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
rtpTimestamp int
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source int
getter/setter pairoverride
timestamp DOMHighResTimeStamp
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited