RTCRtpReceiver class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
jitterBufferTarget DOMHighResTimeStamp?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
track MediaStreamTrack
no setter
transform Object?
getter/setter pair
transport RTCDtlsTransport?
no setter

Methods

getContributingSources() List<RTCRtpContributingSource>
getParameters() RTCRtpReceiveParameters
getStats() Future<RTCStatsReport>
getSynchronizationSources() List<RTCRtpSynchronizationSource>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited