RTCRtpStreamStatsValue class final

Implemented types

Constructors

RTCRtpStreamStatsValue({required int ssrc, required String kind, String? transportId, String? codecId})

Properties

codecId String?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
kind String
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssrc int
getter/setter pairoverride
transportId String?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited