ReactCompositionEvent<T extends EventTarget> class abstract interface

Implemented types

Properties

bubbles bool
no setterinherited
cancelable bool
no setterinherited
currentTarget → T
no setterinherited
defaultPrevented bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target EventTarget
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopPropagation() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited