ReadableByteStreamController class abstract interface

Properties

byobRequest ReadableStreamBYOBRequest?
no setter
desiredSize double?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
enqueue(ArrayBufferView chunk) → void
error([Object? e]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited