RemotePlayback class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
onconnect EventHandler?
getter/setter pair
onconnecting EventHandler?
getter/setter pair
ondisconnect EventHandler?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state RemotePlaybackState
no setter

Methods

cancelWatchAvailability([int? id]) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prompt() Future<void>
toString() RemotePlaybackState
A string representation of this object.
inherited
watchAvailability(RemotePlaybackAvailabilityCallback callback) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited