Properties
-
borderBoxSize
→ List<
ResizeObserverSize> -
no setter
-
contentBoxSize
→ List<
ResizeObserverSize> -
no setter
- contentRect → DOMRectReadOnly
-
no setter
-
devicePixelContentBoxSize
→ List<
ResizeObserverSize> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → Element
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited