RouterCondition class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
not RouterCondition?
getter/setter pair
or List<RouterCondition>?
getter/setter pair
requestDestination ClientType?
getter/setter pair
requestMethod ClientType?
getter/setter pair
requestMode ClientType?
getter/setter pair
runningStatus ClientType?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlPattern Object?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited