Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pathLength → SVGAnimatedNumber
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPointAtLength(
double distance) → DOMPoint -
getTotalLength(
) → double -
isPointInFill(
[DOMPointInit? point]) → bool -
isPointInStroke(
[DOMPointInit? point]) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited