SVGGradientElement class abstract interface

Properties

gradientTransform SVGAnimatedTransformList
no setter
gradientUnits SVGAnimatedEnumeration
no setter
hashCode int
The hash code for this object.
no setterinherited
href SVGAnimatedString
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spreadMethod SVGAnimatedEnumeration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited