SVGMarkerElement class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
markerHeight SVGAnimatedLength
no setter
markerUnits SVGAnimatedEnumeration
no setter
markerWidth SVGAnimatedLength
no setter
orient String
getter/setter pair
orientAngle SVGAnimatedAngle
no setter
orientType SVGAnimatedEnumeration
no setter
preserveAspectRatio SVGAnimatedPreserveAspectRatio
no setter
refX SVGAnimatedLength
no setter
refY SVGAnimatedLength
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewBox SVGAnimatedRect
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOrientToAngle(SVGAngle angle) → void
setOrientToAuto() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited