SVGPatternElement class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
height SVGAnimatedLength
no setter
href SVGAnimatedString
no setter
patternContentUnits SVGAnimatedEnumeration
no setter
patternTransform SVGAnimatedTransformList
no setter
patternUnits SVGAnimatedEnumeration
no setter
preserveAspectRatio SVGAnimatedPreserveAspectRatio
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewBox SVGAnimatedRect
no setter
width SVGAnimatedLength
no setter
x SVGAnimatedLength
no setter
y SVGAnimatedLength
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited