SVGTextPathElement class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
href SVGAnimatedString
no setter
method SVGAnimatedEnumeration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing SVGAnimatedEnumeration
no setter
startOffset SVGAnimatedLength
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited