- Implementers
Properties
-
attributes
↔ List<
SanitizerAttribute> ? -
getter/setter pair
- comments ↔ bool?
-
getter/setter pair
- dataAttributes ↔ bool?
-
getter/setter pair
-
elements
↔ List<
SanitizerAttribute> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
removeAttributes
↔ List<
SanitizerAttribute> ? -
getter/setter pair
-
removeElements
↔ List<
SanitizerAttribute> ? -
getter/setter pair
-
replaceWithChildrenElements
↔ List<
SanitizerAttribute> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited