SecurityPolicyViolationEventInit class abstract interface

Implementers

Properties

blockedURI String?
getter/setter pair
columnNumber int?
getter/setter pair
disposition String?
getter/setter pair
documentURI String?
getter/setter pair
effectiveDirective String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lineNumber int?
getter/setter pair
originalPolicy String?
getter/setter pair
referrer String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample String?
getter/setter pair
sourceFile String?
getter/setter pair
statusCode int?
getter/setter pair
violatedDirective String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() SecurityPolicyViolationEventDisposition
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited