Sensor class abstract interface

Properties

activated bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasReading bool
no setter
onactivate EventHandler?
getter/setter pair
onerror EventHandler?
getter/setter pair
onreading EventHandler?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DOMHighResTimeStamp?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited