SerialInputSignalsValue class final

Implemented types

Constructors

SerialInputSignalsValue({required bool dataCarrierDetect, required bool clearToSend, required bool ringIndicator, required bool dataSetReady})

Properties

clearToSend bool
getter/setter pairoverride
dataCarrierDetect bool
getter/setter pairoverride
dataSetReady bool
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
ringIndicator bool
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited