- Implementers
Properties
- baudRate ↔ int
-
getter/setter pair
- bufferSize ↔ int?
-
getter/setter pair
- dataBits ↔ Object?
-
getter/setter pair
- flowControl ↔ FlowControlType?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- parity ↔ FlowControlType?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopBits ↔ Object?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited