SpeechSynthesisEventInitValue class final

Implemented types

Constructors

SpeechSynthesisEventInitValue({required SpeechSynthesisUtterance utterance, int? charIndex, int? charLength, double? elapsedTime, String? name})

Properties

charIndex int?
getter/setter pairoverride
charLength int?
getter/setter pairoverride
elapsedTime double?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utterance SpeechSynthesisUtterance
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited