TouchEvent class abstract interface

Constructors

TouchEvent(String type_, [TouchEventInit? eventInitDict])
factory

Properties

altKey bool
no setter
changedTouches TouchList
no setter
ctrlKey bool
no setter
hashCode int
The hash code for this object.
no setterinherited
metaKey bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftKey bool
no setter
targetTouches TouchList
no setter
touches TouchList
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() TouchType
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited