UALowEntropyJSONValue class final

Implemented types

Constructors

UALowEntropyJSONValue({List<NavigatorUABrandVersion>? brands, bool? mobile, String? platform})

Properties

brands List<NavigatorUABrandVersion>?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
mobile bool?
getter/setter pairoverride
platform String?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited