USBDeviceFilter class abstract interface

Implementers

Properties

classCode Object?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
productId int?
getter/setter pair
protocolCode Object?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
getter/setter pair
subclassCode Object?
getter/setter pair
vendorId int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited