USBPermissionDescriptorValue class final

Implemented types

Constructors

USBPermissionDescriptorValue({List<USBDeviceFilter>? filters, List<USBDeviceFilter>? exclusionFilters})

Properties

exclusionFilters List<USBDeviceFilter>?
getter/setter pairoverride
filters List<USBDeviceFilter>?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited