VTTCue class abstract interface

Constructors

VTTCue(double startTime, double endTime, String text)
factory

Properties

align AlignSetting
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
line LineAndPositionSetting
getter/setter pair
lineAlign AlignSetting
getter/setter pair
position LineAndPositionSetting
getter/setter pair
positionAlign AlignSetting
getter/setter pair
region VTTRegion?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
getter/setter pair
snapToLines bool
getter/setter pair
text AlignSetting
getter/setter pair
vertical AlignSetting
getter/setter pair

Methods

getCueAsHTML() DocumentFragment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() AlignSetting
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited