VideoDecoderConfig class abstract interface

Implementers

Properties

codec String
getter/setter pair
codedHeight int?
getter/setter pair
codedWidth int?
getter/setter pair
colorSpace VideoColorSpaceInit?
getter/setter pair
description BufferSource?
getter/setter pair
displayAspectHeight int?
getter/setter pair
displayAspectWidth int?
getter/setter pair
hardwareAcceleration AudioSampleFormat?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
optimizeForLatency bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited