VideoEncoderConfig class abstract interface

Implementers

Properties

alpha AvcBitstreamFormat?
getter/setter pair
avc AvcEncoderConfig?
getter/setter pair
bitrate int?
getter/setter pair
bitrateMode AvcBitstreamFormat?
getter/setter pair
codec String
getter/setter pair
contentHint AvcBitstreamFormat?
getter/setter pair
displayHeight int?
getter/setter pair
displayWidth int?
getter/setter pair
framerate double?
getter/setter pair
hardwareAcceleration AvcBitstreamFormat?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
hevc HevcEncoderConfig?
getter/setter pair
latencyMode AvcBitstreamFormat?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalabilityMode AvcBitstreamFormat?
getter/setter pair
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited