VideoFrameInit class abstract interface

Implementers

Properties

alpha AudioSampleFormat?
getter/setter pair
displayHeight int?
getter/setter pair
displayWidth int?
getter/setter pair
duration int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata VideoFrameMetadata?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int?
getter/setter pair
visibleRect DOMRectInit?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited