Properties
- canvas → Object
-
no setter
- drawingBufferColorSpace ↔ String
-
getter/setter pair
- drawingBufferFormat → int
-
no setter
- drawingBufferHeight → int
-
no setter
- drawingBufferWidth → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unpackColorSpace ↔ String
-
getter/setter pair
Methods
-
activeTexture(
GLenum texture) → void -
attachShader(
WebGLProgram program, WebGLShader shader) → void -
bindAttribLocation(
WebGLProgram program, GLuint index, String name) → void -
bindBuffer(
GLenum target, WebGLBuffer? buffer) → void -
bindFramebuffer(
GLenum target, WebGLFramebuffer? framebuffer) → void -
bindRenderbuffer(
GLenum target, WebGLRenderbuffer? renderbuffer) → void -
bindTexture(
GLenum target, WebGLTexture? texture) → void -
blendColor(
GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha) → void -
blendEquation(
GLenum mode) → void -
blendEquationSeparate(
GLenum modeRGB, GLenum modeAlpha) → void -
blendFunc(
GLenum sfactor, GLenum dfactor) → void -
blendFuncSeparate(
GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha) → void -
bufferData(
GLenum target, GLsizeiptr size, GLenum usage) → void -
bufferSubData(
GLenum target, GLintptr offset, AllowSharedBufferSource data) → void -
checkFramebufferStatus(
GLenum target) → GLenum -
clear(
GLbitfield mask) → void -
clearColor(
GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha) → void -
clearDepth(
GLclampf depth) → void -
clearStencil(
GLint s) → void -
colorMask(
GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha) → void -
compileShader(
WebGLShader shader) → void -
compressedTexImage2D(
GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, ArrayBufferView data) → void -
compressedTexSubImage2D(
GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, ArrayBufferView data) → void -
copyTexImage2D(
GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border) → void -
copyTexSubImage2D(
GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height) → void -
createBuffer(
) → WebGLBuffer? -
createFramebuffer(
) → WebGLFramebuffer? -
createProgram(
) → WebGLProgram? -
createRenderbuffer(
) → WebGLRenderbuffer? -
createShader(
GLenum type_) → WebGLShader? -
createTexture(
) → WebGLTexture? -
cullFace(
GLenum mode) → void -
deleteBuffer(
WebGLBuffer? buffer) → void -
deleteFramebuffer(
WebGLFramebuffer? framebuffer) → void -
deleteProgram(
WebGLProgram? program) → void -
deleteRenderbuffer(
WebGLRenderbuffer? renderbuffer) → void -
deleteShader(
WebGLShader? shader) → void -
deleteTexture(
WebGLTexture? texture) → void -
depthFunc(
GLenum func) → void -
depthMask(
GLboolean flag) → void -
depthRange(
GLclampf zNear, GLclampf zFar) → void -
detachShader(
WebGLProgram program, WebGLShader shader) → void -
disable(
GLenum cap) → void -
disableVertexAttribArray(
GLuint index) → void -
drawArrays(
GLenum mode, GLint first, GLsizei count) → void -
drawElements(
GLenum mode, GLsizei count, GLenum type_, GLintptr offset) → void -
drawingBufferStorage(
GLenum sizedFormat, int width, int height) → void -
enable(
GLenum cap) → void -
enableVertexAttribArray(
GLuint index) → void -
finish(
) → void -
flush(
) → void -
framebufferRenderbuffer(
GLenum target, GLenum attachment, GLenum renderbuffertarget, WebGLRenderbuffer? renderbuffer) → void -
framebufferTexture2D(
GLenum target, GLenum attachment, GLenum textarget, WebGLTexture? texture, GLint level) → void -
frontFace(
GLenum mode) → void -
generateMipmap(
GLenum target) → void -
getActiveAttrib(
WebGLProgram program, GLuint index) → WebGLActiveInfo? -
getActiveUniform(
WebGLProgram program, GLuint index) → WebGLActiveInfo? -
getAttachedShaders(
WebGLProgram program) → List< WebGLShader> ? -
getAttribLocation(
WebGLProgram program, String name) → GLint -
getBufferParameter(
GLenum target, GLenum pname) → Object -
getContextAttributes(
) → WebGLContextAttributes? -
getError(
) → int -
getExtension(
String name) → Object? -
getFramebufferAttachmentParameter(
GLenum target, GLenum attachment, GLenum pname) → Object -
getParameter(
GLenum pname) → Object -
getProgramInfoLog(
WebGLProgram program) → String? -
getProgramParameter(
WebGLProgram program, GLenum pname) → Object -
getRenderbufferParameter(
GLenum target, GLenum pname) → Object -
getShaderInfoLog(
WebGLShader shader) → String? -
getShaderParameter(
WebGLShader shader, GLenum pname) → Object -
getShaderPrecisionFormat(
GLenum shadertype, GLenum precisiontype) → WebGLShaderPrecisionFormat? -
getShaderSource(
WebGLShader shader) → String? -
getSupportedExtensions(
) → List< String> ? -
getTexParameter(
GLenum target, GLenum pname) → Object -
getUniform(
WebGLProgram program, WebGLUniformLocation location) → Object -
getUniformLocation(
WebGLProgram program, String name) → WebGLUniformLocation? -
getVertexAttrib(
GLuint index, GLenum pname) → Object -
getVertexAttribOffset(
GLuint index, GLenum pname) → GLintptr -
hint(
GLenum target, GLenum mode) → void -
isBuffer(
WebGLBuffer? buffer) → GLboolean -
isContextLost(
) → bool -
isEnabled(
GLenum cap) → GLboolean -
isFramebuffer(
WebGLFramebuffer? framebuffer) → GLboolean -
isProgram(
WebGLProgram? program) → GLboolean -
isRenderbuffer(
WebGLRenderbuffer? renderbuffer) → GLboolean -
isShader(
WebGLShader? shader) → GLboolean -
isTexture(
WebGLTexture? texture) → GLboolean -
lineWidth(
GLfloat width) → void -
linkProgram(
WebGLProgram program) → void -
makeXRCompatible(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pixelStorei(
GLenum pname, GLint param) → void -
polygonOffset(
GLfloat factor, GLfloat units) → void -
readPixels(
GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type_, ArrayBufferView? pixels) → void -
renderbufferStorage(
GLenum target, GLenum internalformat, GLsizei width, GLsizei height) → void -
sampleCoverage(
GLclampf value, GLboolean invert) → void -
scissor(
GLint x, GLint y, GLsizei width, GLsizei height) → void -
shaderSource(
WebGLShader shader, String source) → void -
stencilFunc(
GLenum func, GLint ref, GLuint mask) → void -
stencilFuncSeparate(
GLenum face, GLenum func, GLint ref, GLuint mask) → void -
stencilMask(
GLuint mask) → void -
stencilMaskSeparate(
GLenum face, GLuint mask) → void -
stencilOp(
GLenum fail, GLenum zfail, GLenum zpass) → void -
stencilOpSeparate(
GLenum face, GLenum fail, GLenum zfail, GLenum zpass) → void -
texImage2D(
GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type_, ArrayBufferView? pixels) → void -
texParameterf(
GLenum target, GLenum pname, GLfloat param) → void -
texParameteri(
GLenum target, GLenum pname, GLint param) → void -
texSubImage2D(
GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type_, ArrayBufferView? pixels) → void -
toString(
) → String -
A string representation of this object.
inherited
-
uniform1f(
WebGLUniformLocation? location, GLfloat x) → void -
uniform1fv(
WebGLUniformLocation? location, Float32List v) → void -
uniform1i(
WebGLUniformLocation? location, GLint x) → void -
uniform1iv(
WebGLUniformLocation? location, Int32List v) → void -
uniform2f(
WebGLUniformLocation? location, GLfloat x, GLfloat y) → void -
uniform2fv(
WebGLUniformLocation? location, Float32List v) → void -
uniform2i(
WebGLUniformLocation? location, GLint x, GLint y) → void -
uniform2iv(
WebGLUniformLocation? location, Int32List v) → void -
uniform3f(
WebGLUniformLocation? location, GLfloat x, GLfloat y, GLfloat z) → void -
uniform3fv(
WebGLUniformLocation? location, Float32List v) → void -
uniform3i(
WebGLUniformLocation? location, GLint x, GLint y, GLint z) → void -
uniform3iv(
WebGLUniformLocation? location, Int32List v) → void -
uniform4f(
WebGLUniformLocation? location, GLfloat x, GLfloat y, GLfloat z, GLfloat w) → void -
uniform4fv(
WebGLUniformLocation? location, Float32List v) → void -
uniform4i(
WebGLUniformLocation? location, GLint x, GLint y, GLint z, GLint w) → void -
uniform4iv(
WebGLUniformLocation? location, Int32List v) → void -
uniformMatrix2fv(
WebGLUniformLocation? location, GLboolean transpose, Float32List value) → void -
uniformMatrix3fv(
WebGLUniformLocation? location, GLboolean transpose, Float32List value) → void -
uniformMatrix4fv(
WebGLUniformLocation? location, GLboolean transpose, Float32List value) → void -
useProgram(
WebGLProgram? program) → void -
validateProgram(
WebGLProgram program) → void -
vertexAttrib1f(
GLuint index, GLfloat x) → void -
vertexAttrib1fv(
GLuint index, Float32List values) → void -
vertexAttrib2f(
GLuint index, GLfloat x, GLfloat y) → void -
vertexAttrib2fv(
GLuint index, Float32List values) → void -
vertexAttrib3f(
GLuint index, GLfloat x, GLfloat y, GLfloat z) → void -
vertexAttrib3fv(
GLuint index, Float32List values) → void -
vertexAttrib4f(
GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w) → void -
vertexAttrib4fv(
GLuint index, Float32List values) → void -
vertexAttribPointer(
GLuint index, GLint size, GLenum type_, GLboolean normalized, GLsizei stride, GLintptr offset) → void -
viewport(
GLint x, GLint y, GLsizei width, GLsizei height) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- activeAttributes → const int
- activeTextureConstant → const int
- activeUniforms → const int
- aliasedLineWidthRange → const int
- aliasedPointSizeRange → const int
- alpha → const int
- alphaBits → const int
- always → const int
- arrayBuffer → const int
- arrayBufferBinding → const int
- attachedShaders → const int
- back → const int
- blend → const int
- blendColorConstant → const int
- blendDstAlpha → const int
- blendDstRgb → const int
- blendEquationAlpha → const int
- blendEquationConstant → const int
- blendEquationRgb → const int
- blendSrcAlpha → const int
- blendSrcRgb → const int
- blueBits → const int
- bool_ → const int
- boolVec2 → const int
- boolVec3 → const int
- boolVec4 → const int
- browserDefaultWebgl → const int
- bufferSize → const int
- bufferUsage → const int
- byte → const int
- ccw → const int
- clampToEdge → const int
- colorAttachment0 → const int
- colorBufferBit → const int
- colorClearValue → const int
- colorWritemask → const int
- compileStatus → const int
- compressedTextureFormats → const int
- constantAlpha → const int
- constantColor → const int
- contextLostWebgl → const int
- cullFaceConstant → const int
- cullFaceMode → const int
- currentProgram → const int
- currentVertexAttrib → const int
- cw → const int
- decr → const int
- decrWrap → const int
- deleteStatus → const int
- depthAttachment → const int
- depthBits → const int
- depthBufferBit → const int
- depthClearValue → const int
- depthComponent → const int
- depthComponent16 → const int
- depthFuncConstant → const int
- depthRangeConstant → const int
- depthStencil → const int
- depthStencilAttachment → const int
- depthTest → const int
- depthWritemask → const int
- dither → const int
- dontCare → const int
- dstAlpha → const int
- dstColor → const int
- dynamicDraw → const int
- elementArrayBuffer → const int
- elementArrayBufferBinding → const int
- equal → const int
- fastest → const int
- float → const int
- floatMat2 → const int
- floatMat3 → const int
- floatMat4 → const int
- floatVec2 → const int
- floatVec3 → const int
- floatVec4 → const int
- fragmentShader → const int
- framebuffer → const int
- framebufferAttachmentObjectName → const int
- framebufferAttachmentObjectType → const int
- framebufferAttachmentTextureCubeMapFace → const int
- framebufferAttachmentTextureLevel → const int
- framebufferBinding → const int
- framebufferComplete → const int
- framebufferIncompleteAttachment → const int
- framebufferIncompleteDimensions → const int
- framebufferIncompleteMissingAttachment → const int
- framebufferUnsupported → const int
- front → const int
- frontAndBack → const int
- frontFaceConstant → const int
- funcAdd → const int
- funcReverseSubtract → const int
- funcSubtract → const int
- generateMipmapHint → const int
- gequal → const int
- greater → const int
- greenBits → const int
- highFloat → const int
- highInt → const int
- implementationColorReadFormat → const int
- implementationColorReadType → const int
- incr → const int
- incrWrap → const int
- int_ → const int
- intVec2 → const int
- intVec3 → const int
- intVec4 → const int
- invalidEnum → const int
- invalidFramebufferOperation → const int
- invalidOperation → const int
- invalidValue → const int
- invert → const int
- keep → const int
- lequal → const int
- less → const int
- linear → const int
- linearMipmapLinear → const int
- linearMipmapNearest → const int
- lineLoop → const int
- lines → const int
- lineStrip → const int
- lineWidthConstant → const int
- linkStatus → const int
- lowFloat → const int
- lowInt → const int
- luminance → const int
- luminanceAlpha → const int
- maxCombinedTextureImageUnits → const int
- maxCubeMapTextureSize → const int
- maxFragmentUniformVectors → const int
- maxRenderbufferSize → const int
- maxTextureImageUnits → const int
- maxTextureSize → const int
- maxVaryingVectors → const int
- maxVertexAttribs → const int
- maxVertexTextureImageUnits → const int
- maxVertexUniformVectors → const int
- maxViewportDims → const int
- mediumFloat → const int
- mediumInt → const int
- mirroredRepeat → const int
- nearest → const int
- nearestMipmapLinear → const int
- nearestMipmapNearest → const int
- never_ → const int
- nicest → const int
- noError → const int
- none → const int
- notequal → const int
- one → const int
- oneMinusConstantAlpha → const int
- oneMinusConstantColor → const int
- oneMinusDstAlpha → const int
- oneMinusDstColor → const int
- oneMinusSrcAlpha → const int
- oneMinusSrcColor → const int
- outOfMemory → const int
- packAlignment → const int
- points → const int
- polygonOffsetFactor → const int
- polygonOffsetFill → const int
- polygonOffsetUnits → const int
- redBits → const int
- renderbuffer → const int
- renderbufferAlphaSize → const int
- renderbufferBinding → const int
- renderbufferBlueSize → const int
- renderbufferDepthSize → const int
- renderbufferGreenSize → const int
- renderbufferHeight → const int
- renderbufferInternalFormat → const int
- renderbufferRedSize → const int
- renderbufferStencilSize → const int
- renderbufferWidth → const int
- renderer → const int
- repeat → const int
- replace → const int
- rgb → const int
- rgb5A1 → const int
- rgb565 → const int
- rgba → const int
- rgba4 → const int
- rgba8 → const int
- sampleAlphaToCoverage → const int
- sampleBuffers → const int
- sampleCoverageConstant → const int
- sampleCoverageInvert → const int
- sampleCoverageValue → const int
- sampler2d → const int
- samplerCube → const int
- samples → const int
- scissorBox → const int
- scissorTest → const int
- shaderType → const int
- shadingLanguageVersion → const int
- short → const int
- srcAlpha → const int
- srcAlphaSaturate → const int
- srcColor → const int
- staticDraw → const int
- stencilAttachment → const int
- stencilBackFail → const int
- stencilBackFunc → const int
- stencilBackPassDepthFail → const int
- stencilBackPassDepthPass → const int
- stencilBackRef → const int
- stencilBackValueMask → const int
- stencilBackWritemask → const int
- stencilBits → const int
- stencilBufferBit → const int
- stencilClearValue → const int
- stencilFail → const int
- stencilFuncConstant → const int
- stencilIndex8 → const int
- stencilPassDepthFail → const int
- stencilPassDepthPass → const int
- stencilRef → const int
- stencilTest → const int
- stencilValueMask → const int
- stencilWritemask → const int
- streamDraw → const int
- subpixelBits → const int
- texture → const int
- texture0 → const int
- texture1 → const int
- texture2 → const int
- texture2d → const int
- texture3 → const int
- texture4 → const int
- texture5 → const int
- texture6 → const int
- texture7 → const int
- texture8 → const int
- texture9 → const int
- texture10 → const int
- texture11 → const int
- texture12 → const int
- texture13 → const int
- texture14 → const int
- texture15 → const int
- texture16 → const int
- texture17 → const int
- texture18 → const int
- texture19 → const int
- texture20 → const int
- texture21 → const int
- texture22 → const int
- texture23 → const int
- texture24 → const int
- texture25 → const int
- texture26 → const int
- texture27 → const int
- texture28 → const int
- texture29 → const int
- texture30 → const int
- texture31 → const int
- textureBinding2d → const int
- textureBindingCubeMap → const int
- textureCubeMap → const int
- textureCubeMapNegativeX → const int
- textureCubeMapNegativeY → const int
- textureCubeMapNegativeZ → const int
- textureCubeMapPositiveX → const int
- textureCubeMapPositiveY → const int
- textureCubeMapPositiveZ → const int
- textureMagFilter → const int
- textureMinFilter → const int
- textureWrapS → const int
- textureWrapT → const int
- triangleFan → const int
- triangles → const int
- triangleStrip → const int
- unpackAlignment → const int
- unpackColorspaceConversionWebgl → const int
- unpackFlipYWebgl → const int
- unpackPremultiplyAlphaWebgl → const int
- unsignedByte → const int
- unsignedInt → const int
- unsignedShort → const int
- unsignedShort565 → const int
- unsignedShort4444 → const int
- unsignedShort5551 → const int
- validateStatus → const int
- vendor → const int
- version → const int
- vertexAttribArrayBufferBinding → const int
- vertexAttribArrayEnabled → const int
- vertexAttribArrayNormalized → const int
- vertexAttribArrayPointer → const int
- vertexAttribArraySize → const int
- vertexAttribArrayStride → const int
- vertexAttribArrayType → const int
- vertexShader → const int
- viewportConstant → const int
- zero → const int