WebSocket class abstract interface

Constructors

WebSocket(String url, [Object? protocols])
factory

Properties

binaryType String
getter/setter pair
bufferedAmount int
no setter
extensions String
no setter
hashCode int
The hash code for this object.
no setterinherited
onclose EventHandler?
getter/setter pair
onerror EventHandler?
getter/setter pair
onmessage EventHandler?
getter/setter pair
onopen EventHandler?
getter/setter pair
protocol String
no setter
readyState int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
no setter

Methods

close([int? code, String? reason]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object data) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited