WebTransport class abstract interface

Constructors

WebTransport(String url, [WebTransportOptions? options])
factory

Properties

closed Future<WebTransportCloseInfo>
no setter
datagrams WebTransportDatagramDuplexStream
no setter
hashCode int
The hash code for this object.
no setterinherited
incomingBidirectionalStreams ReadableStream
no setter
incomingUnidirectionalStreams ReadableStream
no setter
ready Future<void>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close([WebTransportCloseInfo? closeInfo]) → void
createBidirectionalStream([WebTransportSendStreamOptions? options]) Future<WebTransportBidirectionalStream>
createUnidirectionalStream([WebTransportSendStreamOptions? options]) Future<Object>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited