WebTransportConnectionStats class abstract interface

Implementers

Properties

bytesLost int?
getter/setter pair
bytesReceived int?
getter/setter pair
bytesSent int?
getter/setter pair
datagrams WebTransportDatagramStats?
getter/setter pair
estimatedSendRate int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
minRtt DOMHighResTimeStamp?
getter/setter pair
packetsLost int?
getter/setter pair
packetsReceived int?
getter/setter pair
packetsSent int?
getter/setter pair
rttVariation DOMHighResTimeStamp?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smoothedRtt DOMHighResTimeStamp?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited