WebTransportDatagramStatsValue class final

Implemented types

Constructors

WebTransportDatagramStatsValue({int? droppedIncoming, int? expiredIncoming, int? expiredOutgoing, int? lostOutgoing})

Properties

droppedIncoming int?
getter/setter pairoverride
expiredIncoming int?
getter/setter pairoverride
expiredOutgoing int?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
lostOutgoing int?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited