WebTransportOptions class abstract interface

Implementers

Properties

allowPooling bool?
getter/setter pair
anticipatedConcurrentIncomingBidirectionalStreams int?
getter/setter pair
anticipatedConcurrentIncomingUnidirectionalStreams int?
getter/setter pair
congestionControl String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
requireUnreliable bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverCertificateHashes List<WebTransportHash>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited