XMLHttpRequestEventTarget class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
onabort EventHandler?
getter/setter pair
onerror EventHandler?
getter/setter pair
onload EventHandler?
getter/setter pair
onloadend EventHandler?
getter/setter pair
onloadstart EventHandler?
getter/setter pair
onprogress EventHandler?
getter/setter pair
ontimeout EventHandler?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited