XRQuadLayerInitValue class final

Implemented types

Constructors

XRQuadLayerInitValue({XRTextureType? textureType, XRRigidTransform? transform, double? width, double? height})

Properties

hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textureType XRTextureType?
getter/setter pairoverride
transform XRRigidTransform?
getter/setter pairoverride
width double?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited