XRRenderStateInitValue class final

Implemented types

Constructors

XRRenderStateInitValue({double? depthNear, double? depthFar, double? inlineVerticalFieldOfView, Object? baseLayer, List<Object>? layers})

Properties

baseLayer Object?
getter/setter pairoverride
depthFar double?
getter/setter pairoverride
depthNear double?
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
inlineVerticalFieldOfView double?
getter/setter pairoverride
layers List<Object>?
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited