HTMLButtonElement class abstract interface

Constructors

HTMLButtonElement()
factory

Properties

disabled bool
getter/setter pair
form HTMLFormElement?
no setter
formAction String
getter/setter pair
formEnctype String
getter/setter pair
formMethod String
getter/setter pair
formNoValidate bool
getter/setter pair
formTarget String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels NodeList
no setter
name String
getter/setter pair
popoverTargetAction String
getter/setter pair
popoverTargetElement Element?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ String
getter/setter pair
validationMessage String
no setter
validity ValidityState
no setter
value String
getter/setter pair
willValidate bool
no setter

Methods

checkValidity() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportValidity() bool
setCustomValidity(String error) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited