Constructors
- HTMLOptionElement()
-
factory
Properties
- defaultSelected ↔ bool
-
getter/setter pair
- disabled ↔ bool
-
getter/setter pair
- form → HTMLFormElement?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
no setter
- label ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected ↔ bool
-
getter/setter pair
- text ↔ String
-
getter/setter pair
- value ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited