HTMLSelectElement class abstract interface

Constructors

HTMLSelectElement()
factory

Properties

autocomplete String
getter/setter pair
disabled bool
getter/setter pair
form HTMLFormElement?
no setter
hashCode int
The hash code for this object.
no setterinherited
labels NodeList
no setter
length int
getter/setter pair
multiple bool
getter/setter pair
name String
getter/setter pair
options HTMLOptionsCollection
no setter
required_ bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex int
getter/setter pair
selectedOptions HTMLCollection
no setter
size int
getter/setter pair
type_ String
no setter
validationMessage String
no setter
validity ValidityState
no setter
value String
getter/setter pair
willValidate bool
no setter

Methods

add(Object element, [Object? before]) → void
checkValidity() bool
item(int index) HTMLOptionElement?
namedItem(String name) HTMLOptionElement?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(int index) → void
reportValidity() bool
setCustomValidity(String error) → void
showPicker() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited