Constructors
- HTMLTextAreaElement()
-
factory
Properties
- autocomplete ↔ String
-
getter/setter pair
- cols ↔ int
-
getter/setter pair
- defaultValue ↔ String
-
getter/setter pair
- dirName ↔ String
-
getter/setter pair
- disabled ↔ bool
-
getter/setter pair
- form → HTMLFormElement?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → NodeList
-
no setter
- maxLength ↔ int
-
getter/setter pair
- minLength ↔ int
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- placeholder ↔ String
-
getter/setter pair
- readOnly ↔ bool
-
getter/setter pair
- required_ ↔ bool
-
getter/setter pair
- rows ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionDirection ↔ String
-
getter/setter pair
- selectionEnd ↔ int
-
getter/setter pair
- selectionStart ↔ int
-
getter/setter pair
- textLength → int
-
no setter
- type_ → String
-
no setter
- validationMessage → String
-
no setter
- validity → ValidityState
-
no setter
- value ↔ String
-
getter/setter pair
- willValidate → bool
-
no setter
- wrap ↔ String
-
getter/setter pair
Methods
-
checkValidity(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reportValidity(
) → bool -
select(
) → void -
setCustomValidity(
String error) → void -
setRangeText(
String replacement, int start, int end, [SelectionMode? selectionMode]) → void -
setSelectionRange(
int start, int end, [String? direction]) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited