Properties
- assignedSlot → HTMLSlotElement?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wholeText → String
-
no setter
Methods
-
convertPointFromNode(
DOMPointInit point, GeometryNode from, [ConvertCoordinateOptions? options]) → DOMPoint -
convertQuadFromNode(
DOMQuadInit quad, GeometryNode from, [ConvertCoordinateOptions? options]) → DOMQuad -
convertRectFromNode(
DOMRectReadOnly rect, GeometryNode from, [ConvertCoordinateOptions? options]) → DOMQuad -
getBoxQuads(
[BoxQuadOptions? options]) → List< DOMQuad> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
splitText(
int offset) → Text -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited