UnsupportedWebApiError class final

Thrown by generated SSR members for Web APIs that exist in the surface but are not executable on the server. Never return null where the IDL type is non-null just to accommodate SSR.

Inheritance

Constructors

UnsupportedWebApiError(String api, {String? exposed})

Properties

api String
final
exposed String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited