Properties
- channelCount ↔ int
-
getter/setter pair
- channelCountMode ↔ String
-
getter/setter pair
- channelInterpretation ↔ String
-
getter/setter pair
- context → BaseAudioContext
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- numberOfInputs → int
-
no setter
- numberOfOutputs → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
AudioNode destinationNode, [int? output, int? input]) → AudioNode -
disconnect(
AudioNode destinationNode, int output, int input) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited