Constructors
- CSSStyleSheet([CSSStyleSheetInit? options])
-
factory
Properties
- cssRules → CSSRuleList
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ownerRule → CSSRule?
-
no setter
- rules → CSSRuleList
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRule(
[String? selector, String? style, int? index]) → int -
deleteRule(
int index) → void -
insertRule(
Object rule, [int? index]) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeRule(
[int? index]) → void -
replace(
String text) → Future< CSSStyleSheet> -
replaceSync(
String text) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited