Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setter
- onmessage ↔ EventHandler?
-
getter/setter pair
- onmessageerror ↔ EventHandler?
-
getter/setter pair
- onrtctransform ↔ EventHandler?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelAnimationFrame(
int handle) → void -
close(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postMessage(
Object message, List< Object> transfer) → void -
requestAnimationFrame(
FrameRequestCallback callback) → int -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited