HkdfParamsValue class final
- Implemented types
Constructors
- HkdfParamsValue({required HashAlgorithmIdentifier hash, required BufferSource salt, required BufferSource info})
Properties
- hash ↔ BufferSource
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- info ↔ BufferSource
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salt ↔ BufferSource
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited