Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyPath → Object
-
no setter
- multiEntry → bool
-
no setter
- name ↔ IDBCursorDirection
-
getter/setter pair
- objectStore → IDBObjectStore
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unique → bool
-
no setter
Methods
-
count(
[Object? query]) → IDBRequest -
get_(
Object query) → IDBRequest -
getAll(
[Object? query, int? count]) → IDBRequest -
getAllKeys(
[Object? query, int? count]) → IDBRequest -
getKey(
Object query) → IDBRequest -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openCursor(
[Object? query, IDBCursorDirection? direction]) → IDBRequest -
openKeyCursor(
[Object? query, IDBCursorDirection? direction]) → IDBRequest -
toString(
) → IDBCursorDirection -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited