IntersectionObserverInitValue class final
- Implemented types
Constructors
- IntersectionObserverInitValue({Object? root, String? rootMargin, String? scrollMargin, Object? threshold})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- root ↔ Object?
-
getter/setter pairoverride
- rootMargin ↔ String?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollMargin ↔ String?
-
getter/setter pairoverride
- threshold ↔ Object?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited