Constructors
- KeyboardEvent(String type_, [KeyboardEventInit? eventInitDict])
-
factory
Properties
- altKey → bool
-
no setter
- charCode → int
-
no setter
- code → String
-
no setter
- ctrlKey → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComposing → bool
-
no setter
- key → String
-
no setter
- keyCode → int
-
no setter
- location → int
-
no setter
- metaKey → bool
-
no setter
- repeat → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shiftKey → bool
-
no setter
Methods
-
getModifierState(
String keyArg) → bool -
initKeyboardEvent(
String typeArg, [bool? bubblesArg, bool? cancelableArg, Window? viewArg, String? keyArg, int? locationArg, bool? ctrlKey, bool? altKey, bool? shiftKey, bool? metaKey]) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited