MessageEvent class abstract interface

Constructors

MessageEvent(String type_, [MessageEventInit? eventInitDict])
factory

Properties

data Object
no setter
hashCode int
The hash code for this object.
no setterinherited
lastEventId String
no setter
origin String
no setter
ports List<MessagePort>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Object?
no setter

Methods

initMessageEvent(String type_, [bool? bubbles, bool? cancelable, Object? data, String? origin, String? lastEventId, MessageEventSource? source, List<MessagePort>? ports]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited