NotificationOptionsValue class final
- Implemented types
Constructors
-
NotificationOptionsValue({NotificationDirection? dir, String? lang, String? body, String? tag, String? image, String? icon, String? badge, VibratePattern? vibrate, EpochTimeStamp? timestamp, bool? renotify, bool? silent, bool? requireInteraction, Object? data, List<
NotificationAction> ? actions})
Properties
-
actions
↔ List<
NotificationAction> ? -
getter/setter pairoverride
- badge ↔ String?
-
getter/setter pairoverride
- body ↔ String?
-
getter/setter pairoverride
- data ↔ Object?
-
getter/setter pairoverride
- dir ↔ String?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ String?
-
getter/setter pairoverride
- image ↔ String?
-
getter/setter pairoverride
- lang ↔ String?
-
getter/setter pairoverride
- renotify ↔ bool?
-
getter/setter pairoverride
- requireInteraction ↔ bool?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- silent ↔ bool?
-
getter/setter pairoverride
- tag ↔ String?
-
getter/setter pairoverride
- timestamp ↔ EpochTimeStamp?
-
getter/setter pairoverride
- vibrate ↔ Object?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited