Constructors
-
PaymentRequest(List<
PaymentMethodData> methodData, PaymentDetailsInit details) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- onpaymentmethodchange ↔ EventHandler?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
abort(
) → Future< void> -
canMakePayment(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show_(
[Future< PaymentDetailsUpdate> ? detailsPromise]) → Future<PaymentResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited