ProfilerTraceValue class final
- Implemented types
Constructors
-
ProfilerTraceValue({required List<
ProfilerResource> resources, required List<ProfilerFrame> frames, required List<ProfilerStack> stacks, required List<ProfilerSample> samples})
Properties
-
frames
↔ List<
ProfilerFrame> -
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resources
↔ List<
ProfilerResource> -
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
samples
↔ List<
ProfilerSample> -
getter/setter pairoverride
-
stacks
↔ List<
ProfilerStack> -
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited