RTCErrorInitValue class final
- Implemented types
Constructors
- RTCErrorInitValue({int? httpRequestStatusCode, required RTCErrorDetailType errorDetail, int? sdpLineNumber, int? sctpCauseCode, int? receivedAlert, int? sentAlert})
Properties
- errorDetail ↔ String
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpRequestStatusCode ↔ int?
-
getter/setter pairoverride
- receivedAlert ↔ int?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sctpCauseCode ↔ int?
-
getter/setter pairoverride
- sdpLineNumber ↔ int?
-
getter/setter pairoverride
- sentAlert ↔ int?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited