Properties
- dx → SVGAnimatedNumber
-
no setter
- dy → SVGAnimatedNumber
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → SVGAnimatedLength
-
no setter
- in1 → SVGAnimatedString
-
no setter
- result → SVGAnimatedString
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stdDeviationX → SVGAnimatedNumber
-
no setter
- stdDeviationY → SVGAnimatedNumber
-
no setter
- width → SVGAnimatedLength
-
no setter
- x → SVGAnimatedLength
-
no setter
- y → SVGAnimatedLength
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setStdDeviation(
double stdDeviationX, double stdDeviationY) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited