Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unitType → int
-
no setter
- value ↔ double
-
getter/setter pair
- valueAsString ↔ String
-
getter/setter pair
- valueInSpecifiedUnits ↔ double
-
getter/setter pair
Methods
-
convertToSpecifiedUnits(
int unitType) → void -
newValueSpecifiedUnits(
int unitType, double valueInSpecifiedUnits) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited