Properties
- activeElement → Element?
-
no setter
-
adoptedStyleSheets
↔ List<
CSSStyleSheet> -
getter/setter pair
- clonable → bool
-
no setter
- delegatesFocus → bool
-
no setter
- fullscreenElement → Element?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → Element
-
no setter
- innerHTML ↔ Object
-
getter/setter pair
- mode → String
-
no setter
- onslotchange ↔ EventHandler?
-
getter/setter pair
- pictureInPictureElement → Element?
-
no setter
- pointerLockElement → Element?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializable → bool
-
no setter
- slotAssignment → String
-
no setter
- styleSheets → StyleSheetList
-
no setter
Methods
-
getAnimations(
) → List< Animation> -
getHTML(
[GetHTMLOptions? options]) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setHTMLUnsafe(
Object html) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited