StreamPipeOptionsValue class final
- Implemented types
Constructors
- StreamPipeOptionsValue({bool? preventClose, bool? preventAbort, bool? preventCancel, AbortSignal? signal})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- preventAbort ↔ bool?
-
getter/setter pairoverride
- preventCancel ↔ bool?
-
getter/setter pairoverride
- preventClose ↔ bool?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signal ↔ AbortSignal?
-
getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited