Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
multiDrawArraysInstancedWEBGL(GLenum mode, Object firstsList, int firstsOffset, Object countsList, int countsOffset, Object instanceCountsList, int instanceCountsOffset, GLsizei drawcount)
→ void
-
-
multiDrawArraysWEBGL(GLenum mode, Object firstsList, int firstsOffset, Object countsList, int countsOffset, GLsizei drawcount)
→ void
-
-
multiDrawElementsInstancedWEBGL(GLenum mode, Object countsList, int countsOffset, GLenum type_, Object offsetsList, int offsetsOffset, Object instanceCountsList, int instanceCountsOffset, GLsizei drawcount)
→ void
-
-
multiDrawElementsWEBGL(GLenum mode, Object countsList, int countsOffset, GLenum type_, Object offsetsList, int offsetsOffset, GLsizei drawcount)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited