Methods
-
atob(String data)
→ String
-
-
btoa(String data)
→ String
-
-
clearInterval([int? id])
→ void
-
-
clearTimeout([int? id])
→ void
-
-
createImageBitmap(ImageBitmapSource image, int sx, int sy, int sw, int sh, [ImageBitmapOptions? options])
→ Future<ImageBitmap>
-
-
fetch(RequestInfo input, [RequestInit? init])
→ Future<Response>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
queueMicrotask(VoidFunction callback)
→ void
-
-
reportError(Object e)
→ void
-
-
setInterval(TimerHandler handler, [int? timeout, List<Object>? arguments])
→ int
-
-
setTimeout(TimerHandler handler, [int? timeout, List<Object>? arguments])
→ int
-
-
structuredClone(Object value, [StructuredSerializeOptions? options])
→ Object
-
-
toString()
→ IDBCursorDirection
-
A string representation of this object.
inherited