Properties
- gamepad → Gamepad?
-
no setter
- gripSpace → XRSpace?
-
no setter
- hand → XRHand?
-
no setter
- handedness → XRHandedness
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
profiles
→ List<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetRayMode → XRHandedness
-
no setter
- targetRaySpace → XRSpace
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → XRHandedness -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited