- Implementers
Properties
- clearOnAccess ↔ bool?
-
getter/setter pair
- colorFormat ↔ GLenum?
-
getter/setter pair
- depthFormat ↔ GLenum?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStatic ↔ bool?
-
getter/setter pair
- layout ↔ XRTextureType?
-
getter/setter pair
- mipLevels ↔ GLenum?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- space ↔ XRSpace
-
getter/setter pair
- viewPixelHeight ↔ int
-
getter/setter pair
- viewPixelWidth ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited