SsrWebRuntime class final
SSR runtime: most live Web APIs throw; host elements are handled by the virtual host-node pipeline.
- Implemented types
Constructors
- SsrWebRuntime()
-
const
Properties
Methods
-
createWebObject<
T extends Object> (String name, List< Object?> arguments) → T -
Constructs a backend instance of a neutral constructible Web API
(e.g. BroadcastChannel) from its IDL constructor arguments.
override
-
getNamespaceProperty(
String namespace, String property) → dynamic -
Reads a namespace attribute.
override
-
invokeNamespace(
String namespace, String member, List< Object?> arguments) → dynamic -
Invokes a namespace operation (e.g.
CSS.supports()).override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setNamespaceProperty(
String namespace, String property, Object? value) → void -
Writes a namespace attribute.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited