The runtime backend installed by a browser or SSR entry point.
- Implementers
Properties
Methods
-
createWebObject<
T extends Object> (String name, List< Object?> arguments) → T - Constructs a backend instance of a neutral constructible Web API (e.g. BroadcastChannel) from its IDL constructor arguments.
-
getNamespaceProperty(
String namespace, String property) → dynamic - Reads a namespace attribute.
-
invokeNamespace(
String namespace, String member, List< Object?> arguments) → dynamic -
Invokes a namespace operation (e.g.
CSS.supports()). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setNamespaceProperty(
String namespace, String property, Object? value) → void - Writes a namespace attribute.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current → WebRuntime
-
no setter
Static Methods
-
install(
WebRuntime runtime) → void